@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Transport::Bolt;
 # ABSTRACT: Adapter for Neo4j::Bolt
-$Neo4j::Driver::Transport::Bolt::VERSION = '0.11';
+$Neo4j::Driver::Transport::Bolt::VERSION = '0.12';
 
 use Carp qw(croak);
 our @CARP_NOT = qw(Neo4j::Driver::Transaction);
@@ -26,8 +26,8 @@ sub new {
 		$uri->userinfo( $driver->{auth}->{principal} . ':' . $driver->{auth}->{credentials} );
 	}
 	
-	my $cxn = Neo4j::Bolt->connect_("$uri");
-	croak "Unauthorized" unless $cxn;
+	my $cxn = Neo4j::Bolt->connect("$uri");
+	croak 'Bolt error ' . $cxn->errnum . ' ' . $cxn->errmsg unless $cxn && $cxn->connected;
 	
 	return bless {
 		connection => $cxn,
@@ -35,6 +35,9 @@ sub new {
 	}, $class;
 }
 
+# libneo4j-client error numbers:
+# https://github.com/cleishm/libneo4j-client/blob/master/lib/src/neo4j-client.h.in
+
 
 # Prepare query statement, including parameters. When multiple statements
 # are to be combined in a single server communication, this method allows
@@ -47,34 +50,63 @@ sub prepare {
 }
 
 
-# Send statements to the Neo4j server and return all results. Will either
-# continue to use the existing open server transaction or create a new one
-# (iff the server transaction is not yet open).
+# Send statements to the Neo4j server and return all results.
 sub run {
 	my ($self, $tx, @statements) = @_;
 	
 	# multiple statements not yet supported for Bolt
 	my ($statement) = @statements;
 	
-	my ($stream, $json);
+	my ($stream, $json, $summary);
 	if ($statement->[0]) {
-		$stream = $self->{connection}->run_query_( @$statement );
+		$stream = $self->{connection}->run_query( @$statement );
 		
-		# There is some sort of strange problem passing the stream along
+		croak 'Bolt error ' . $self->{connection}->errnum . ' ' . $self->{connection}->errmsg unless $stream;
+		
+		# There is some sort of strange problem passing any data structures
+		# that come from the Neo4j::Bolt result stream along
 		# to StatementResult. As a workaround, for now we consume the full
 		# stream right here and re-create the JSON result data structure.
-		my @names = $stream->fieldnames_;
+		# Not sure if this issue occurs outside the tests.
+		my @names = $stream->field_names;
 		my @data = ();
-		while ( my @row = $stream->fetch_next_ ) {
-			push @data, { row => \@row };
+		while ( my @row = $stream->fetch_next ) {
+			
+			croak 'next true and failure/success mismatch: ' . $stream->failure . '/' . $stream->success unless $stream->failure == -1 || $stream->success == -1 || ($stream->failure xor $stream->success);  # assertion
+			croak 'next true and error: client ' . $stream->client_errnum . ' ' . $stream->client_errmsg . '; server ' . $stream->server_errcode . ' ' . $stream->server_errmsg if $stream->failure && $stream->failure != -1;
+			
+			push @data, { row => \@row, meta => [] };
 		}
+		
+		croak 'next false and failure/success mismatch: ' . $stream->failure . '/' . $stream->success unless  $stream->failure == -1 || $stream->success == -1 || ($stream->failure xor $stream->success);  # assertion
+		croak 'next false and error: client ' . $stream->client_errnum . ' ' . $stream->client_errmsg . '; server ' . $stream->server_errcode . ' ' . $stream->server_errmsg if $stream->failure && $stream->failure != -1;
+		
+		my $stats = {};
+		my @counters = qw(
+			nodes_created
+			nodes_deleted
+			relationships_created
+			properties_set
+			labels_added
+			labels_removed
+			indexes_added
+			indexes_removed
+			constraints_added
+			constraints_removed
+		);
+		for my $c (@counters) { eval {$stats->{$c} = $stream->update_counts()->{$c} } }
+		eval {$stats->{relationship_deleted} = $stream->update_counts()->{relationships_deleted}};
+		
 		$json = {
 			columns => \@names,
 			data => \@data,
+			stats => $stats,
 		};
+		my $statement_summary = {statement => shift @$statement};
+		$statement_summary->{parameters} = $statement->[0];
+		$summary = Neo4j::Driver::ResultSummary->new( $json, {}, $statement_summary );
 	}
 	
-	my $summary;  # not yet implemented
 	my $result = Neo4j::Driver::StatementResult->new( $json, $summary );
 	return ($result);
 }
@@ -152,7 +184,7 @@ Neo4j::Driver::Transport::Bolt - Adapter for Neo4j::Bolt
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
